@@ -15,6 +15,7 @@ deal faster when it works).
 #c This program is free software, covered by the GNU GPL.  See the
 #c COPYING file in the source distribution.
 
+import functools
 
 from gavo.adql import common
 from gavo.adql import morphhelpers
@@ -593,12 +594,43 @@ def _fixSetLimit(node, state):
 		offset=offset)
 
 
+@functools.lru_cache(None)
+def _needsMaterialization():
+	"""returns True if CTEs need to be explitly materialised on our
+	current server to make them planner barriers.
+	"""
+	from gavo import base
+	return base.getPgVersion()[0]>11
+
+def _materializeIfNecessary(node, state):
+	"""Makes sure CTEs are materialized.
+
+	starting with version 12, postgres will inline CTEs unless
+	they're explicitly materialised.  Since we've materialised them
+	before, for consistency we make sure they are materialised in newer
+	postgres-es as well.  We should probably have some way to have users
+	order us to not do it.
+	"""
+	if _needsMaterialization():
+		for index, token in enumerate(node.children):
+			if token=='AS':
+				break
+		else:
+			raise PostgresMorphError("CTE seems to be missing an AS?")
+
+		index += 1
+		node.children = node.children[:index]+(
+			"MATERIALIZED",)+node.children[index:]
+		return node
+
+
 _syntaxMorphers = {
 	"selectNoParens": _insertPGSC,
 	'comparisonPredicate': morphhelpers.booleanizeComparisons,
 	'selectList': _expandStars,
 	'derivedColumn': _forceAlias,
 	"selectQuery": _fixSetLimit,
+	"withQuery": _materializeIfNecessary,
 }
 
 # Warning: if ever there are two Morphers for the same type, this will
