@@ -452,13 +452,22 @@ def _string_agg(args):
 	""",
 	returntype="spoint")
 def _ivo_apply_pm(args):
-	if len(args)!=5:
+	if len(args)==5:
+		# there's no indexing or anything to gain here; drop through to an
+		# implementation in the database.
+		#
+		# This is the legacy ("gavo") implementation that we probably
+		# want to drop.
+		return None
+	elif len(args)==6:
+		# This is the ESAC-compliant ("ivo") implementation that we probably
+		# want to keep.
+		return None
+	else:
 		raise common.UfuncError(
 			"ivo_apply_pm requires exactly ra, dec, pmra, pmdec, epdist.")
 
-	# there's no indexing or anything to gain here; drop through to an
-	# implementation in the database.
-	return None
+	
 
 
 # the healpix functions are currently available in a pgsphere fork
