@@ -77,13 +77,13 @@ from gavo.base.sqlsupport import (getDBConnection,
 	getTableConn, getAdminConn, getUntrustedConn,
 	getWritableTableConn, getWritableAdminConn, getWritableUntrustedConn,
 	setDBMeta, getDBMeta,
+	getPgVersion,
 	NUMERIC_TYPES, ORDERED_TYPES,
 	NonBlockingQuery)
 
 from gavo.base.structure import (Structure, ParseableStructure, 
 	DataContent, makeStruct, RestrictionMixin)
 
-
 from gavo.base.typesystems import *
 
 from gavo.base.valuemappers import (SerManager, ValueMapperFactoryRegistry,
@@ -96,7 +96,7 @@ from gavo.base.unitconv import (
 	computeConversionFactor, parseUnit, computeColumnConversions,
 	getSpecExpr,
 	IncompatibleUnits, BadUnit, 
-	LIGHT_C, PLANCK_H)
+	LIGHT_C, PLANCK_H, BOLTZMANN_K)
 
 from gavo.base.xmlstruct import parseFromString, parseFromStream, feedTo
 
