@@ -129,10 +129,17 @@ class _DictAttributeParser(common.Parser):
 	The parser keeps state in the _key and _adding attributes and needs to
 	be _reset after use.
 	"""
-	def __init__(self, dict, nextParser, parseValue, keyName, inverted=False):
+	def __init__(self, 
+			dict, 
+			nextParser, 
+			parseValue, 
+			keyName, 
+			inverted=False,
+			expander=None):
 		self.dict, self.nextParser, self.parseValue = (
 			dict, nextParser, parseValue)
-		self.keyName, self.inverted = keyName, inverted
+		self.keyName, self.inverted, self.expander = (
+			keyName, inverted, expander)
 		self._reset()
 
 	def _reset(self):
@@ -149,16 +156,27 @@ class _DictAttributeParser(common.Parser):
 	def value_(self, ctx, name, value):
 		if name=="key" or name==self.keyName:
 			self._key = value
+
 		elif name=="cumulate":
 			self._adding = literals.parseBooleanLiteral(value)
+
 		elif name=="content_":
 			if self._key is attrdef.Undefined:
 				raise common.StructureError("Content '%s' has no %s attribute"%(
 					value, self.keyName))
-			self.addPair(self._key, self.parseValue(value))
+			value = self.parseValue(value)
+
+			if (self.expander 
+					and isinstance(value, str)
+					and "\\" in value):
+				value = self.expander.expand(value)
+
+			self.addPair(self._key, value)
 			self._reset()
+
 		else:
 			raise common.StructureError('No "%s" attributes on mappings'%name)
+
 		return self
 	
 	def start_(self, ctx, name, value):
@@ -197,13 +215,14 @@ class DictAttribute(attrdef.AttributeDef):
 	def __init__(self, name, description="Undocumented", 
 			itemAttD=attrdef.UnicodeAttribute("value"), 
 			keyName="key", 
-			inverted=False, **kwargs):
+			inverted=False, expandMacros=False, **kwargs):
 		attrdef.AttributeDef.__init__(self, name, 
 			attrdef.Computed, description, **kwargs)
 		self.xmlName_ = itemAttD.name_
 		self.itemAttD = itemAttD
 		self.keyName = keyName
 		self.inverted = inverted
+		self.expandMacros = expandMacros
 
 	@property
 	def typeDesc_(self):
@@ -218,9 +237,14 @@ class DictAttribute(attrdef.AttributeDef):
 		self.doCallbacks(instance, value)
 
 	def create(self, parent, ctx, name):
+		expander = None
+		if self.expandMacros and hasattr(parent, "expand"):
+			expander = parent
+
 		return _DictAttributeParser(getattr(parent, self.name_), 
 			parent, self.itemAttD.parse, keyName=self.keyName,
-			inverted=self.inverted)
+			inverted=self.inverted,
+			expander=expander)
 
 	def iterEvents(self, instance):
 		for key, value in getattr(instance, self.name_).items():
@@ -262,7 +286,7 @@ class PropertyAttribute(DictAttribute):
 	def __init__(self, description="Properties (i.e., user-defined"
 			" key-value pairs) for the element.", **kwargs):
 		DictAttribute.__init__(self, "properties", description=description, 
-			keyName="name", **kwargs)
+			keyName="name", expandMacros=True, **kwargs)
 		self.xmlName_ = "property"
 	
 	def iterParentMethods(self):
