@@ -54,7 +54,6 @@ DEPRECATED_ATOMS = {
 }
 
 
-
 class MetaError(utils.Error):
 	"""A base class for metadata-related errors.
 
@@ -419,7 +418,7 @@ class MetaAttribute(attrdef.AttributeDef):
 			yield ev
 
 
-class MetaMixin(object):
+class MetaMixin(common.StructCallbacks):
 	"""is a mixin for entities carrying meta information.
 
 	The meta mixin provides the followng methods:
@@ -465,7 +464,12 @@ class MetaMixin(object):
 	def setMetaParent(self, parent):
 		if parent is not None:
 			self.__metaParent = parent
-	
+
+	def setParent(self, parent):
+		if hasattr(parent, "_getMeta"):
+			self.setMetaParent(parent)
+		super().setParent(parent)
+
 	def getMetaParent(self):
 		if self.__hasMetaParent():
 			return self.__metaParent
