@@ -493,7 +493,7 @@ def _parseTableName(tableName, schema=None):
 		return schema.lower(), name.lower()
 
 
-def parseBannerString(bannerString, digits=2):
+def _parseBannerString(bannerString):
 	"""returns digits from a postgres server banner.
 
 	This hardcodes the response given by postgres 8 and raises a ValueError
@@ -503,7 +503,18 @@ def parseBannerString(bannerString, digits=2):
 	if not mat:
 		raise ValueError("Cannot make out the Postgres server version from %s"%
 			repr(bannerString))
-	return ".".join(mat.group(1).split(".")[:digits])
+	return tuple(int(s) for s in mat.group(1).split("."))
+
+
+def getPgVersion(digits=2):
+	"""returns the version number of the postgres server executing
+	untrusted (ADQL) queries.
+
+	This is relatively expensive, as it will actually ask the server.
+	"""
+	with getUntrustedConn() as conn:
+		bannerString = list(conn.query("SELECT version()"))[0][0]
+		return _parseBannerString(bannerString)
 
 
 class PostgresQueryMixin(object):
@@ -512,11 +523,6 @@ class PostgresQueryMixin(object):
 	This mixin expects a parent that mixes is QuerierMixin (that, for now,
 	also mixes in PostgresQueryMixin, so you won't need to mix this in).
 	"""
-	def getServerVersion(self, digits=2):
-		"""returns the version of the connection's server to digits numbers.
-		"""
-		bannerString = list(self.connection.query("SELECT version()"))[0][0]
-		return parseBannerString(bannerString, digits)
 
 	def getPrimaryIndexName(self, tableName):
 		"""returns the name of the index corresponding to the primary key on 
