@@ -31,8 +31,9 @@ class IncompatibleUnits(utils.Error):
 class BadUnit(utils.Error):
 	pass
 
-PLANCK_H = 6.626070040e-34
+PLANCK_H = 6.62607015e-34
 LIGHT_C = 299792458.0
+BOLTZMANN_K = 1.380649e-23
 
 
 # We can't yet restructure the tree, so we don't do SI-base-casting for
@@ -45,7 +46,7 @@ PLAIN_UNITS = units = {
 	"\xc5": (1e-10, "m"),
 	"Angstrom": (1e-10, "m"),
 	"angstrom": (1e-10, "m"),
-	"AU": (1.49598e11, "m"), 
+	"AU": (1.495978701e11, "m"), # as per ESA/SP-1200
 	"arcmin": (math.pi/180./60., "rad"), 
 	"arcsec": (math.pi/180./3600., "rad"), 
 	"barn": (1, "barn"),  # 1e-28 m2
