@@ -291,7 +291,42 @@ def _iterDatalinkResources(ctx, dataSet):
 					" could not be satisfied (%s)"%(
 						getattr(table.tableDef.rd, "sourceId", "<internal>"),
 						ex))
-	
+
+
+def _iterUniqueInfosFromMeta(
+		ctx, metaCarriers, metaKey, infoName, ucd, infoText):
+	"""yields standard INFOs from meta items on a sequence of metaCarriers.
+
+	metaKey references the meta items to make INFOs from.  InfoName and
+	ucd are set on the INFO elements, infoText will be formatted
+	into the body text, where this functions locals are template arguments.
+	That includes value as the INFO's value.
+
+	For when the UCD depends on the INFO's value, ucd can also be
+	a callable, which receives the value and must return the UCD.
+
+	The function makes sure that no item is returned more than once.
+	"""
+	seenItems = set()
+	if ctx.version<(1,2):
+		# No UCD on INFO for ancient VOTables
+		ucd = None
+
+	for mc in metaCarriers:
+		for metaValue in mc.iterMeta(metaKey, propagate=True):
+			value = metaValue.getContent("text")
+			if value in seenItems:
+				continue
+			seenItems.add(value)
+
+			if callable(ucd):
+				thisUCD = ucd(value)
+			else:
+				thisUCD = ucd
+
+			yield V.INFO(name=infoName, value=value, ucd=thisUCD)[
+				infoText.format(**locals())]
+
 
 def _iterResourceMeta(ctx, dataSet):
 	"""adds resource metadata to the Resource parent.
@@ -302,36 +337,29 @@ def _iterResourceMeta(ctx, dataSet):
 			_iterInfoInfos(dataSet), _iterWarningInfos(dataSet)):
 		yield el
 
-	sourcesSeen, citeLinksSeen = set(), set()
-	for table in list(dataSet.tables.values()):
-		for m in table.iterMeta("source", propagate="True"):
-			src = m.getContent("text")
+	sources = list(dataSet.tables.values())
 
-			ucd = None
-			if ctx.version>(1,1):
-				if utils.couldBeABibcode(src):
-					ucd = "meta.bib.bibcode"
-				else:
-					ucd = "meta.bib"
-					
-			if src not in sourcesSeen:
-				yield V.INFO(name="citation", value=src, ucd=ucd)[
-					"This resource contains data associated with the publication"
-					" %s."%src]
-			sourcesSeen.add(src)
+	yield from _iterUniqueInfosFromMeta(ctx, sources,
+		"source",
+		"citation",
+		lambda value: "meta.bib.bibcode" 
+			if utils.couldBeABibcode(value)
+			else "meta.bib",
+		"This resource contains data associated with the publication {value}")
 
-		if ctx.version>(1,1):
-			ucd = "meta.bib"
-		else:
-			ucd = None
+	yield from _iterUniqueInfosFromMeta(ctx, sources,
+		"howtociteLink",
+		"citation",
+		"meta.bib",
+		"For advice on how to cite the resource(s) that contributed"
+		" to this result, see {value}")
 
-		for m in table.iterMeta("howtociteLink"):
-			link = m.getContent("text")
-			if link not in citeLinksSeen:
-				yield V.INFO(name="citation", value=link, ucd=ucd)[
-					"For advice on how to cite the resource(s)"
-					" that contributed to this result, see %s"%link]
-			citeLinksSeen.add(link)
+	yield from _iterUniqueInfosFromMeta(ctx, sources,
+		"referenceURL",
+		"referenceURL",
+		"meta.ref.url",
+		"More information on a resource that contributed to this data is"
+		" found at {value}")
 
 
 def _iterToplevelMeta(ctx, dataSet):
