@@ -277,7 +277,7 @@ class MapKeys(base.Structure):
 	def onElementComplete(self):
 		if self.content_:
 			self._parseShortenedMap(self.content_)
-		self._onElementCompleteNext(MapKeys)
+		super().onElementComplete()
 
 	def doMap(self, aDict):
 		"""returns dict with the keys mapped according to the defined mappings.
@@ -496,7 +496,7 @@ class FileRowIterator(RowIterator):
 			self.inputFile.close()
 
 
-class FileRowAttributes(object):
+class FileRowAttributes(base.StructCallbacks):
 	"""A mixin for grammars with FileRowIterators.
 
 	This provides some attributes that FileRowIterators interpret, e.g.,
@@ -514,7 +514,7 @@ class FileRowAttributes(object):
 		if ctx.restricted:
 			if self.preFilter is not None:
 				raise base.RestrictedElement("preFilter")
-		self._completeElementNext(FileRowAttributes, ctx)
+		super().completeElement(ctx)
 
 
 class GrammarMacroMixin(base.StandardMacroMixin):
@@ -675,9 +675,8 @@ class Grammar(base.Structure, GrammarMacroMixin):
 		childFactory=Rowfilter, copyable=True)
 	_ignoreOn = base.StructAttribute("ignoreOn", default=None, copyable=True,
 		description="Conditions for ignoring certain input records.  These"
-			" triggers drop an input record entirely.  If you feed multiple"
-			" tables and just want to drop a row from a specific table, you"
-			" can use ignoreOn in a rowmaker.",
+			" triggers drop an input record entirely.  In modern RDs, prefer"
+			" rowfilters raising SkipThis.",
 		childFactory=rowtriggers.IgnoreOn)
 	_sourceFields = base.StructAttribute("sourceFields", default=None,
 		copyable=True, description="Code returning a dictionary of values"
