@@ -235,7 +235,7 @@ class DirectGrammar(base.Structure, base.RestrictionMixin):
 	isDispatching = False
 
 	def validate(self):
-		self._validateNext(DirectGrammar)
+		super().validate()
 		if self.type=='bin':
 			if not self.recordSize:
 				raise base.StructureError("DirectGrammars reading from binary need"
