@@ -6,7 +6,7 @@ WARNING: This messes up some global state.  DO NOT import into modules
 doing regular work.  testtricks is the module for that kind for stuff.
 """
 
-#c Copyright 2008-2021, the GAVO project <gavo@ari.uni-heidelberg.de>
+#c Copyright 2008-2022, the GAVO project <gavo@ari.uni-heidelberg.de>
 #c
 #c This program is free software, covered by the GNU GPL.  See the
 #c COPYING file in the source distribution.
@@ -16,6 +16,7 @@ import http.server
 import contextlib
 import gc
 import io
+import importlib
 import os
 import pickle
 import re
@@ -113,6 +114,9 @@ else:
 					"--encoding=UTF-8", "--locale=C", dbname])
 
 				initdachs.initDB(dsn)
+				from gavo.base import sqlsupport
+				# update the type bindings
+				importlib.reload(sqlsupport)
 
 				from gavo.registry import publication
 				from gavo import rsc
@@ -149,9 +153,8 @@ from gavo.base import osinter
 osinter.sendMail = lambda *args, **kwargs: None
 
 from gavo import utils
-from gavo import svcs
 from gavo.base import config
-
+from gavo.base import sqlsupport
 
 class FakeSimbad(object):
 	"""we monkeypatch simbadinterface such that we don't query simbad during
@@ -278,8 +281,7 @@ class TestResource(testresources.TestResource):
 
 
 from gavo.helpers.testtricks import (  #noflake: exported names
-	XSDTestMixin, testFile, getMemDiffer, getXMLTree, collectedEvents,
-	FakeRequest) 
+	XSDTestMixin, testFile, getMemDiffer, getXMLTree, collectedEvents)
 
 
 class ForkingSubprocess(subprocess.Popen):
@@ -871,27 +873,34 @@ def tempConfig(*items):
 			config.getitem(sect, key).value = val
 
 
-def makeRequestArgs(aDict=None, **kwargs):
-	"""returns a request.args compatible dict form aDict.
+@contextlib.contextmanager
+def forceConnection(conn):
+	"""makes the sqlsupport connection context managers return conn
+	in the controlled block.
 
-	In particular, simple values will be put into lists.
+	It is up to the programmer to make sure that actually makes sense
+	in a given test.  As opposed to the originals, there will be no
+	automatic commits here.  Caveat emptor.
 	"""
-	if aDict is None:
-		aDict = {}
-	aDict.update(kwargs)
-	return dict((k,v if isinstance(v, list) else [v])
-		for k, v in aDict.items())
+	symbols = ["getUntrustedConn", "getTableConn", "getAdminConn",
+		"getWritableUntrustedConn", "getWritableTableConn", "getWritableAdminConn"]
 
+	def _():
+		yield conn
+	cm = contextlib.contextmanager(_)
 
-def runSvcWith(service, renderer, args):
-	"""runs svc through renderers, passing a dict args.
-
-	args maps to single values, *not* to lists as in t.w.  Unless, of course,
-	you actually have lists to begin with.
-	"""
-	args = makeRequestArgs(args)
-	queryMeta = svcs.QueryMeta.fromRequestArgs(args)
-	return service.run(renderer, args, queryMeta)
+	originals = []
+	for sym in symbols:
+		originals.append(getattr(sqlsupport, sym))
+		setattr(sqlsupport, sym, cm)
+	
+	try:
+		yield
+	finally:
+		originals.reverse()
+		for sym in symbols:
+			originals.append(getattr(sqlsupport, sym))
+			setattr(sqlsupport, sym, originals.pop())
 
 
 def main(testClass, methodPrefix=None):
