@@ -14,23 +14,16 @@ this.
 
 import contextlib
 import gzip
-import io
 import os
 import re
 import tempfile
 
 from lxml import etree
 
-from twisted.internet  import defer
-from twisted.python import failure
-from twisted.python import urlpath
-from twisted.web import resource
-from twisted.web import server
-from twisted.web.test.requesthelper import DummyRequest
-
 from gavo import base
 from gavo import utils
-from gavo import web
+from gavo.formal.testing import ( #noflake: exported names
+	FakeRequest, assertHasStrings)
 from gavo.utils import stanxml
 
 
@@ -77,6 +70,9 @@ class _WrappedEtree:
 	def getByID(self, id):
 		return self.uniqueXpath("//*[@ID='%s']"%id)
 
+	def asString(self):
+		return etree.tostring(self._tree).decode("utf-8")
+
 
 def getXMLTree(xmlString, debug=False):
 	"""returns an ``libxml2`` etree-like object for ``xmlString``, where, 
@@ -97,6 +93,7 @@ def getXMLTree(xmlString, debug=False):
 	* getById(id), returning the unique element with id and raising an 
 	  assertion error if that doesn't exist.
 	* getByID(id), as getById, by for VOTable-style ID.
+	* asString(), returning a string representation of the tree
 	"""
 	tree = etree.fromstring(_nukeNamespaces(xmlString))
 
@@ -482,7 +479,6 @@ def testFile(name,
 			pass
 
 
-
 @contextlib.contextmanager
 def collectedEvents(*kinds):
 	"""a context manager collecting event arguments for a while.
@@ -506,198 +502,3 @@ def collectedEvents(*kinds):
 	finally:
 		for kind, handler in handlers:
 			base.ui.unsubscribe(kind, handler)
-		
-
-class FakeFile:
-	def __init__(self, filename, fileobj):
-		self.filename, self.file = filename, fileobj
-		if isinstance(self.file, bytes):
-			self.file = io.BytesIO(self.file)
-
-
-class FakeFieldStorage(object):
-	filename = None
-	def __init__(self, args):
-		self.args = {}
-		for k, vals in args.items():
-			res = self.args[k.decode("utf-8")] = []
-			for v in vals:
-				if isinstance(v, bytes):
-					res.append(v.decode("utf-8"))
-				else:
-					res.append(FakeFile(*v))
-
-	def __iter__(self):
-		return iter(self.args)
-	
-	def getfirst(self, key):
-		return self.args[key][0]
-	
-	def getlist(self, key):
-		return self.args[key]
-
-	def __getitem__(self, key):
-		return self.args[key][0]
-
-	def keys(self):
-		return list(self.args.keys())
-
-	@property
-	def file(self):
-		return io.StringIO(self.args[0])
-
-
-def bytify_seq(s):
-	"""returns a list from s with any elements bytified.
-
-	s must be a sequence or None.  Oh, for convenience we also accept plain
-	bytes and strings.
-	"""
-	if s is None:
-		return None
-	if isinstance(s, (bytes, str)):
-		s = [s]
-	if not isinstance(s, (list, tuple)):
-		raise Exception("bytify_seq really wants a sequence, not %s"%repr(s))
-	return [utils.bytify(item) for item in s]
-
-
-class FakeRequest(DummyRequest, web.Request):
-	"""A request for test purposes.
-
-	We furnish t.w's DummyRequest with some extra facilities to let us
-	be a bit lazy in having rather macro tests.
-
-	Also, stock twisted DummyRequest produces an endless loop with push
-	producers (which is what we have), so we fix that, too.
-	"""
-
-	method = b"GET"
-	session = None
-
-	# some code tests for a live connection using client
-	client = True
-
-	def __init__(self, uri=b'', headers=None, args=None, avatar=None,
-                 currentSegments=None, cookies=None,
-                 user="", password="", isSecure=False):
-		uri = utils.bytify(uri)
-		if uri.startswith(b"/"):
-			uri = uri[1:]
-		postpath = []
-		if uri:
-			postpath = uri.split(b"/")
-
-		DummyRequest.__init__(self, uri)
-
-		if args:
-			self.args = dict((utils.bytify(k), bytify_seq(v)) 
-				for k, v in args.items())
-		else:
-			self.args = {}
-
-		self.uri = uri
-		self.postpath = postpath
-		self.code = 200
-		self.user, self.password = user, password
-		self.deferred = defer.Deferred()
-		self.accumulator = b""
-		self.prepath = []
-		self.fields = FakeFieldStorage(self.args)
-		self.finished = False
-		self.secure = False
-		self.channel = 1 # must be non-None for custom hangup detection
-
-	def setHeader(self, name, value):
-# overridden because t.w.t doesn't overwrite
-		self.responseHeaders.setRawHeaders(name, [value])
-
-	def write(self, data):
-		self.accumulator += utils.bytify(data)
-
-	def notifyFinish(self):
-		return self.deferred
-
-	def prePathURL(self):
-		return 'http://%s/%s'%(self.getHost(), '/'.join(self.prepath))
-
-	def finish(self):
-		self.finished = True
-		self.deferred.callback((self.accumulator, self))
-
-	def finishCallback(self, arg):
-		if isinstance(arg, failure.Failure):
-			arg.raiseException()
-		if not self.finished:
-			self.finish()
-
-	def setHost(self, host, port):
-		self.host = host
-	
-	def getHost(self):
-		return self.host
-
-	def setResponseCode(self, code):
-		self.code = code
-
-	def URLPath(self):
-		return urlpath.URLPath.fromString(self.path.decode("utf-8"))
-
-	@property
-	def path(self):
-		return self.uri
-
-	def isSecure(self):
-		return self.secure
-
-	def getLocationValue(self):
-		"""returns a location header if this requests redirects, and raises
-		an AssertionError otherwise.
-		"""
-		if not self.code or self.code//100!=3:
-			raise AssertionError("Trying to get a redirection target for"
-				" request with status %s"%self.code)
-
-		hdrs = self.responseHeaders.getRawHeaders("location")
-		if len(hdrs)!=1:
-			raise AssertionError("Trying to get a redirection target when"
-				" location headers are %s"%hdrs)
-
-		return hdrs[0]
-
-	def processWithRoot(self, page):
-		"""runs this request on page.
-
-		This is probably a bad idea all around, and we should just be using
-		trial.  But since sync tests are quite a bit more convenient,
-		here this is.  Of course, it only works if resource effectively
-		renders sync (or has a renderSync method).
-		"""
-		rsc = resource.getChildForRequest(page, self)
-
-		res = getattr(rsc, "renderSync", rsc.render)(self)
-		if res:
-			if isinstance(res, int) and res==server.NOT_DONE_YET:
-				# this will only work if the thing is actually sync.
-				# see servicetest._syncvosi for an inspration there.
-				# But in that case, accumulator will have it all.
-				pass
-			else:
-				return res
-
-		return self.accumulator
-
-	def registerProducer(self, producer, isPush):
-		self.producer = producer
-		if not isPush:
-			DummyRequest.registerProducer(
-				self, producer, isPush)
-
-	def unregisterProducer(self):
-		# stop twisted pull producers, too
-		self.go = 0
-		self.channel = None
-		del self.producer
-	
-	def getResponseHeader(self, headerName):
-		return self.responseHeaders.getRawHeaders(headerName)[0]
