@@ -74,14 +74,20 @@ def _makeColumnFromFieldInfo(ctx, colName, fi):
 	"""
 	if len(fi.userData)==1:
 		res = svcs.OutputField.fromColumn(fi.userData[0])
+
+		if fi.type!=fi.userData[0].type:
+			res.xtype = None
+
 		if hasattr(fi.userData[0], "originalName"):
 			# the following is to undo column renaming for postgres-forbidden
 			# column names
 			colName = fi.userData[0].originalName
+
 		elif fi.userData[0].name.lower()==colName:
 			# undo case normalisation done by the ADQL machinery
 			# if we're reasonably sure there's no intervening AS
 			colName = fi.userData[0].name
+
 	else: 
 		res = base.makeStruct(svcs.OutputField, name=colName)
 
@@ -273,10 +279,9 @@ def _addTableMeta(translated, query, tree, table):
 					sourceTD.getQName()))
 
 			if not tableMetaCopied:
-				for m in sourceTD.iterMeta("howtociteLink"):
-					table.addMeta("howtociteLink", m)
-				for m in sourceTD.iterMeta("source"):
-					table.addMeta("source", m)
+				for copiedKey in ["howtociteLink", "source", "referenceURL"]:
+					for m in sourceTD.iterMeta(copiedKey, propagate=True):
+						table.addMeta(copiedKey, m)
 
 				for m in sourceTD.iterMeta("_associatedDatalinkService"):
 					idColumn = sourceTD.getColumnByName(
