@@ -63,13 +63,34 @@ def hashMatches(pwIn, storedHash):
 		raise svcs.ForbiddenURI("You passed in an overlong password."
 			"  The server will not even look at it.")
 	if not storedHash.startswith("scrypt:"):
-		raise ValueError("Bad hash serialisation: '%s'"%storedHash)
+		raise ValueError(f"Bad hash serialisation: '{storedHash}'")
 	
 	saltAndHash = base64.b64decode(storedHash[7:])
 	salt, hash = saltAndHash[:16], saltAndHash[16:]
 	return hash==scryptN4(pwIn.encode("utf-8"), salt=salt)
 
 
+@functools.lru_cache(None)
+def getHashedAdminPassword():
+	password = base.getConfig("web", "adminpasswd")
+	if password.startswith("scrypt:"):
+		return password
+	else:
+		return hashPassword(password)
+
+
+def isAdmin(username, password):
+	"""returns True if username and password match what's configured
+	in gavorc.
+	"""
+	if (username=='gavoadmin' 
+			and password
+			and hashMatches(password, getHashedAdminPassword())):
+		return True
+	
+	return False
+
+
 def getGroupsForUser(username, password):
 	"""returns a set of all groups user username belongs to.
 
@@ -83,8 +104,7 @@ def getGroupsForUser(username, password):
 
 	if username is None:
 			return set()
-	if username=='gavoadmin' and (
-			password and password==base.getConfig("web", "adminpasswd")):
+	if isAdmin(username, password):
 		return AllEncompassingSet()
 	query = ("SELECT groupname, password"
 		" FROM dc.groups"
@@ -119,8 +139,7 @@ def hasCredentials(user, password, reqGroup):
 		user = user.decode("utf-8")
 	if isinstance(password, bytes):
 		password = password.decode("utf-8")
-	if user=="gavoadmin" and base.getConfig("web", "adminpasswd"
-			) and password==base.getConfig("web", "adminpasswd"):
+	if isAdmin(user, password):
 		return True
 
 	with base.getAdminConn() as conn:
