@@ -731,7 +731,7 @@ class DatalinkCoreBase(svcs.Core, base.ExpansionDelegator):
 		self.queriedTable = base.caches.getRD("//datalink").getById(
 			"dlresponse")
 
-		self._completeElementNext(DatalinkCoreBase, ctx)
+		super().completeElement(ctx)
 
 	def getMetaForDescriptor(self, descriptor):
 		"""returns a pair of linkDefs, inputKeys for a datalink desriptor
