@@ -155,7 +155,7 @@ class SCSCore(svcs.DBCore):
 	name_ = "scsCore"
 
 	def onElementComplete(self):
-		self._onElementCompleteNext(SCSCore)
+		super().onElementComplete()
 		# raColumn and decColumn must be from the queriedTable (rather than
 		# the outputTable, as it would be preferable), since we're using
 		# them to build database queries.
