@@ -68,7 +68,7 @@ class ResRec(rscdef.IVOMetaMixin, NonServiceResource):
 			" for standards, organisations, instruments, etc.)")
 
 	def onElementComplete(self):
-		self._onElementCompleteNext(ResRec)
+		super().onElementComplete()
 		self.setMetaParent(self.rd)
 
 	def getPublicationsForSet(self, names):
@@ -110,7 +110,7 @@ class DeletedResource(NonServiceResource):
 		return self.resTuple["ivoid"]
 
 	def completeElement(self, ctx):
-		self._completeElementNext(DeletedResource, ctx)
+		super().completeElement(ctx)
 		self.rd = _FakeRD(self.resTuple["sourceRD"])
 		self.id = self.resTuple["resId"]
 		self.setMeta("_metadataUpdated", self.resTuple["recTimestamp"])
