@@ -94,7 +94,7 @@ def makeBaseRecord(res, keepTimestamp=False):
 	rec["deleted"] = False
 	rec["recTimestamp"] = datetime.datetime.utcnow()
 	rec["description"] = base.getMetaText(res, "description")
-	rec["authors"] = "; ".join(m.getContent("text") 
+	rec["authors"] = "; ".join(m.getExpandedContent(res) 
 		for m in res.iterMeta("creator.name", propagate=True))
 	rec["dateUpdated"] = base.getMetaText(res, "_dataUpdated", default=None)
 
@@ -125,7 +125,8 @@ def iterAuthorsAndSubjects(resource, sourceRD, resId):
 	# for authors, we support a special notation, separating individual
 	# authors with semicolons.
 	for authors in resource.iterMeta("creator.name", propagate="True"):
-		authors = [s.strip() for s in authors.getContent("text").split(";")]
+		authors = [s.strip() for s in 
+			authors.getExpandedContent(resource).split(";")]
 		for author in authors:
 			if not author.startswith("et al"):
 				yield ("authors", {
