@@ -233,7 +233,8 @@ def getTablesetForService(
 		tables = [resource]
 
 	elif isinstance(resource, rscdef.DataDescriptor):
-		tables = list(resource.iterTableDefs())
+		tables = [td for td in resource.iterTableDefs()
+			if td.adql and td.adql!="hidden"]
 	
 	else:
 		tables = resource.getTableSet()
@@ -261,7 +262,6 @@ def getTablesetForService(
 			bySchema.setdefault("internal", []).append(t)
 			rdForSchema["internal"] = _INTERNAL_SCHEMA
 
-
 	schemas = []
 	for schemaName, tables in sorted(bySchema.items()):
 		schemas.append((rdForSchema[schemaName], tables))
