@@ -455,10 +455,10 @@ void writeInteger(Field *field, void *destination)
  * intel machines.  This isn't really defined by IEEE, so this might
  * not work for you.
  */
-void mirrorBytes(char *mem, int numBytes)
+void mirrorBytes(unsigned char *mem, int numBytes)
 {
-	char *start = mem;
-	char *end = mem+numBytes-1;
+	unsigned char *start = mem;
+	unsigned char *end = mem+numBytes-1;
 
 	if (__BYTE_ORDER==__BIG_ENDIAN) {
 		return;
@@ -475,7 +475,7 @@ void writeBigint(Field *field, void *destination)
 	uint32_t size=htonl(sizeof(int64_t));
 	int64_t val=field->val.c_int64;
 
-	mirrorBytes((char*)&val, sizeof(int64_t));
+	mirrorBytes((unsigned char*)&val, sizeof(int64_t));
 	DATA_OUT(&size, 4, destination);
 	DATA_OUT(&val, sizeof(int64_t), destination);
 }
@@ -485,7 +485,7 @@ void writeFloat(Field *field, void *destination)
 	uint32_t size=htonl(sizeof(float));
 	float val=field->val.c_float;
 
-	mirrorBytes((char*)&val, sizeof(float));
+	mirrorBytes((unsigned char*)&val, sizeof(float));
 	DATA_OUT(&size, 4, destination);
 	DATA_OUT(&val, sizeof(float), destination);
 }
@@ -495,7 +495,7 @@ void writeDouble(Field *field, void *destination)
 	uint32_t size=htonl(sizeof(double));
 	double val=field->val.c_double;
 
-	mirrorBytes((char*)&val, sizeof(double));
+	mirrorBytes((unsigned char*)&val, sizeof(double));
 	DATA_OUT(&size, 4, destination);
 	DATA_OUT(&val, sizeof(double), destination);
 }
@@ -550,15 +550,23 @@ void writeArray(Field *field, void *destination)
 }
 
 
-/* packFloatArray takes nVals floats and writes the bytes for
-a postgres dump of them into buf.  Buf needs at least nVals*8+36 bytes,
-and  the function will recklessly buffer overflow if you don't provied
+/* packArray takes nVals values of length itemsize from vals. 
+It writes the bytes for a postgres dump of them into buf.  
+Buf needs at least nVals*(4+itemsize)+36 bytes, and  the function 
+will recklessly buffer overflow if you don't provide
 it.  This returns the number for bytes written into buf.
 
 See below for what I'm writing; this is based on 
 backend/utils/adt/arrayfuncs.c of the postgres source and puzzling
 over an actual dump. */
-size_t packFloatArray(unsigned char *buf, float *vals, int nVals)
+size_t packArray(
+	unsigned char *buf,  /* the target buffer */
+	unsigned char *vals, /* the values to serialise */
+	int nVals,           /* number of items in vals */
+	int itemoid,         /* postgres UID of the target type */
+	size_t itemsize,     /* size of each item in vals */
+	int littleEndian     /* have this 1 when incoming data is little-endian */
+	)
 {
 	unsigned char *wp=buf;
 	unsigned int intbuf;
@@ -573,9 +581,8 @@ size_t packFloatArray(unsigned char *buf, float *vals, int nVals)
 	intbuf = 0;
 	ADD_DATA(&intbuf, 4, wp);
 
-	/* (3) The oid of float32s: 700; yeah, it might be unwise to hard-code
-	this here. */
-	intbuf = htonl(700);
+	/* (3) The oid. */
+	intbuf = htonl(itemoid);
 	ADD_DATA(&intbuf, 4, wp);
 
 	/* (4) 32 bits of the the number of elements */
@@ -586,13 +593,15 @@ size_t packFloatArray(unsigned char *buf, float *vals, int nVals)
 	intbuf = htonl(1);
 	ADD_DATA(&intbuf, 4, wp);
 
-	/* (6) for each element, 32 bits of 4 (the size), and then the float. */
+	/* (6) for each element, 32 bits of item size, and then item's bytes. */
 	for (i=0; i<nVals; i++) {
-		float val = vals[i];
-		intbuf = htonl(4);
+		unsigned char *val = vals+i*itemsize;
+		intbuf = htonl(itemsize);
 		ADD_DATA(&intbuf, 4, wp);
-		mirrorBytes((char*)&val, sizeof(float));
-		ADD_DATA(&val, 4, wp);
+		if (littleEndian) {
+			mirrorBytes(val, itemsize);
+		}
+		ADD_DATA(val, itemsize, wp);
 	}
 
 	return wp-buf;
@@ -612,7 +621,7 @@ void writeDatetime(Field *field, void *destination)
 #endif
 	uint32_t size_n=htonl(size);
 
-	mirrorBytes((char*)&usecsSinceEpoch, size);
+	mirrorBytes((unsigned char*)&usecsSinceEpoch, size);
 	DATA_OUT(&size_n, 4, destination);
 	DATA_OUT(&usecsSinceEpoch, size, destination);
 }
