@@ -52,7 +52,9 @@ class ParamNameAttribute(base.UnicodeAttribute):
 	"""An attribute containing a param or column name.
 
 	These, in DaCHS, have to match identifierPat (essentially, like
-	python identifiers.
+	python identifiers).  For compatibility with columns, they do
+	allow the quoted/ prefix, but the only place this is really supported
+	is in query generation.
 	"""
 	@property
 	def typeDesc_(self):
@@ -61,8 +63,12 @@ class ParamNameAttribute(base.UnicodeAttribute):
 			)%utils.identifierPattern.pattern
 	
 	def parse(self, value):
+		if value.startswith("quoted/"):
+			return utils.QuotedName(value[7:])
+
 		if not utils.identifierPattern.match(value):
-			raise base.StructureError("'%s' is not a valid column name"%value)
+			raise base.StructureError(
+				f"'{value}' is not a valid column identifier")
 		return value
 	
 
@@ -264,7 +270,7 @@ class Option(base.Structure):
 	def completeElement(self, ctx):
 		if self.title is base.NotGiven:
 			self.title = str(self.content_)
-		self._completeElementNext(Option, ctx)
+		super().completeElement(ctx)
 
 
 def makeOptions(*args):
@@ -550,11 +556,16 @@ class ColumnBase(base.Structure, base.MetaMixin):
 	def __repr__(self):
 		return "<Column %s>"%repr(self.name)
 
+	def setParent(self, parent):
+		# overridden to turn off automatic meta parenting from MetaMixin.
+		# This does not upcall on purpose.
+		self.parent = parent
+
 	def setMetaParent(self, parent):
 		# columns should *not* take part in meta inheritance.  The reason is
 		# that there are usually many columns to a table, and there's no
 		# way I can see that any piece of metadata should be repeated in
-		# all of them.  On the other hand, for votlinks (no name an example),
+		# all of them.  On the other hand, for votlinks (to name an example),
 		# meta inheritance would have disastrous consequences.
 		# So, we bend the rules a bit.
 		raise base.StructureError("Columns may not have meta parents.",
@@ -582,13 +593,13 @@ class ColumnBase(base.Structure, base.MetaMixin):
 				self.key = self.key.replace(')', "__").replace('(', "__")
 		else:
 			self.key = self.name
-		self._completeElementNext(ColumnBase, ctx)
+		super().completeElement(ctx)
 
 	def isEnumerated(self):
 		return self.values and self.values.options
 
 	def validate(self):
-		self._validateNext(ColumnBase)
+		super().validate()
 		if self.restrictedMode and self.fixup:
 			raise base.RestrictedElement("fixup")
 		if self.xtype=="adql:TIMESTAMP":
@@ -647,6 +658,17 @@ class ColumnBase(base.Structure, base.MetaMixin):
 			else:
 				return False
 
+	def isScalar(self):
+		"""returns true if we consider the array's values as scalar.
+
+		A single string is scalar for us.
+		"""
+		type, arraysize, _ = self._getVOTableType()
+		if type=="char" or type=="unicodeChar":
+			return "x" not in arraysize
+		else:
+			return arraysize is None
+
 	_indexedCleartext = {
 		True: "indexed",
 		False: "notIndexed",
@@ -758,7 +780,7 @@ class Column(ColumnBase):
 		" anything else.", copyable=False)
 
 	def validate(self):
-		self._validateNext(Column)
+		super().validate()
 		# Now check if we can serialize the column safely in VOTables.
 		# I only want to hear about this when the column may end up in
 		# a VOTable; 
@@ -880,10 +902,10 @@ class ParamBase(ColumnBase):
 	def completeElement(self, ctx):
 		if not self.values:
 			self.values = base.makeStruct(Values, parent_=self)
-		self._completeElementNext(ParamBase, ctx)
+		super().completeElement(ctx)
 	
 	def onElementComplete(self):
-		self._onElementCompleteNext(ParamBase)
+		super().onElementComplete()
 		if self.content_ is base.NotGiven:
 			if self.values.default is not None:
 				self.set(self.values.default)
@@ -1061,7 +1083,7 @@ class Param(ParamBase):
 		" with column")
 
 	def validate(self):
-		self._validateNext(Param)
+		super().validate()
 		if self.content_ is base.NotGiven:
 			self.set(None)
 
