@@ -129,7 +129,7 @@ class ProfileListAttribute(base.AtomicAttribute):
 			f" {self.defaultSource_} from gavorc) -- {self.description_}")
 
 
-class PrivilegesMixin(object):
+class PrivilegesMixin(base.StructCallbacks):
 	"""A mixin for structures declaring access to database objects (tables,
 	schemas).
 
@@ -151,7 +151,7 @@ class PrivilegesMixin(object):
 		defaultSource="[db]maintainers")
 
 
-class IVOMetaMixin(object):
+class IVOMetaMixin(base.StructCallbacks):
 	"""A mixin for resources aspiring to have IVO ids.
 
 	All those need to have an RDAttribute.  In return, we're filling
@@ -160,6 +160,9 @@ class IVOMetaMixin(object):
 	by normal setMetas).
 	"""
 	def _meta_referenceURL(self):
+		if self.rd is None:
+			return None
+
 		return base.META_CLASSES_FOR_KEYS["referenceURL"](
 			self.getURL("info"),
 			title="Service info")
@@ -225,7 +228,7 @@ class Registration(base.Structure, base.MetaMixin):
 			self._completeMetadataFromResRow(
 				ctx.getInjected("resprop:%s#%s"%(
 					self.parent.rd.sourceId, self.parent.id), {}))
-		self._completeElementNext(Registration, ctx)
+		super().completeElement(ctx)
 	
 	def publishedForADQL(self):
 		"""returns true if at least one table published is available for
