@@ -76,7 +76,7 @@ class GuardedFunctionFactory(object):
 				serializingLock.release()
 			if execDef.debug and execDef.outputAccum:
 				cron.sendMailToAdmin("Debug output of DaCHS Job %s"%execDef.jobName,
-					"\n".join(execDef.outputAccum))
+					"\n".join(execDef.outputAccum), debug=True)
 				del execDef.outputAccum
 
 		def cronFunction():
@@ -263,7 +263,7 @@ class Execute(base.Structure, base.ExpansionDelegator):
 		return (dom, dow, hour, minute)
 
 	def completeElement(self, ctx):
-		self._completeElementNext(Execute, ctx)
+		super().completeElement(ctx)
 		if len([s for s in [self.at, self.every] if s is base.NotGiven])!=1:
 			raise base.StructureError("Exactly one of at and every required"
 				" for Execute", pos=ctx.pos)
@@ -274,7 +274,7 @@ class Execute(base.Structure, base.ExpansionDelegator):
 				self.parsedAt.append(self._parseAt(literal, ctx))
 
 	def onElementComplete(self):
-		self._onElementCompleteNext(Execute)
+		super().onElementComplete()
 
 		self.jobName = "%s in %s"%(self.title, self.rd.sourceId)
 
