@@ -69,7 +69,7 @@ class MixinPar(procdef.AliasableRDParameter):
 		copyable=True, strip=True, default=base.NotGiven)
 
 	def validate(self):
-		self._validateNext(MixinPar)
+		super().validate()
 		if len(self.key)<2:
 			raise base.LiteralParseError("name", self.key, hint="Names of"
 				" mixin parameters must have at least two characters (since"
@@ -103,8 +103,8 @@ class MixinDef(activetags.ReplayBase):
 	two procedure definitions, viz, processEarly and processLate.
 	These can access the structure that has the mixin as substrate.
 
-	processEarly is called as part of the substrate's completeElement
-	method.  processLate is executed just before the parser exits.  This
+	processEarly is called at the lexical location of the mixin.
+	processLate is executed just before the parser exits.  This
 	is the place to fix up anything that uses the table mixed in.  Note,
 	however, that you should be as conservative as possible here -- you
 	should think of DC structures as immutable as long as possible.
@@ -157,7 +157,7 @@ class MixinDef(activetags.ReplayBase):
 		# necessary because during replay, we have macroExpansions and
 		# macroParent reflect a concrete application's context.
 		self.applicationLock = threading.Lock()
-		self._completeElementNext(MixinDef, ctx)
+		super().completeElement(ctx)
 
 	def _defineMacros(self, fillers, destination):
 		"""creates attributes macroExpansions and parentMacroPackage used by
@@ -325,7 +325,6 @@ class MixinAttribute(base.SetOfAtomsAttribute):
 		actions to be taken in time.
 		"""
 		mixin = ctx.resolveId(mixinRef, instance=instance, forceType=MixinDef)
-
 		base.SetOfAtomsAttribute.feed(self, ctx, instance, mixinRef)
 		mixin.applyTo(instance, ctx, fillers)
 
