@@ -2,7 +2,7 @@
 Basic handling for embedded procedures.
 """
 
-#c Copyright 2008-2021, the GAVO project <gavo@ari.uni-heidelberg.de>
+#c Copyright 2008-2022, the GAVO project <gavo@ari.uni-heidelberg.de>
 #c
 #c This program is free software, covered by the GNU GPL.  See the
 #c COPYING file in the source distribution.
@@ -55,7 +55,7 @@ class RDParameter(base.Structure):
 		return self.content_ is not base.NotGiven
 
 	def validate(self):
-		self._validateNext(RDParameter)
+		super().validate()
 		if not utils.identifierPattern.match(self.key):
 			raise base.LiteralParseError("name", self.key, hint=
 				"The name you supplied was not defined by any procedure definition.")
@@ -64,7 +64,7 @@ class RDParameter(base.Structure):
 		if self.content_=="__EMPTY__":
 			self.content_ = ""
 
-		self._completeElementNext(RDParameter, ctx)
+		super().completeElement(ctx)
 
 
 class AliasableRDParameter(RDParameter):
@@ -86,7 +86,7 @@ class ProcPar(AliasableRDParameter):
 	name_ = "par"
 
 	def validate(self):
-		self._validateNext(ProcPar)
+		super().validate()
 		# Allow non-python syntax when things look like macro calls.
 		if (self.content_ 
 				and not "\\" in self.content_):
@@ -103,7 +103,7 @@ class Binding(ProcPar):
 	name_ = "bind"
 
 	def validate(self):
-		self._validateNext(Binding)
+		super().validate()
 		if not self.content_ or not self.content_.strip():
 			raise base.StructureError("Binding bodies must not be empty.")
 
@@ -320,11 +320,11 @@ class ProcApp(ProcDef):
 						procId,
 						utils.fixIndentation(self.procDef.deprecated, "")))
 
-		self._validateNext(ProcApp)
+		super().validate()
 		self._ensureParsBound()
 
 	def completeElement(self, ctx):
-		self._completeElementNext(ProcApp, ctx)
+		super().completeElement(ctx)
 		if self.name is base.NotGiven:  # make up a name from self's id
 			self.name = ("proc%x"%id(self)).replace("-", "")
 
@@ -367,7 +367,7 @@ class ProcApp(ProcDef):
 				" %s."%(", ".join(bindNames)))
 
 	def onElementComplete(self):
-		self._onElementCompleteNext(ProcApp)
+		super().onElementComplete()
 		self._boundNames = dict((b.key, b.content_) for b in self.bindings)
 
 	def _combineWithProcDef(self, methodName, boundNames):
