@@ -474,7 +474,7 @@ class DataURL(base.Structure):
 				raise base.StructureError("Only POST is allowed as httpMethod"
 					" together with upload")
 
-		self._validateNext(DataURL)
+		super().validate()
 
 
 class RegTest(procdef.ProcApp, unittest.TestCase):
@@ -756,7 +756,7 @@ class RegTestSuite(base.Structure):
 	def completeElement(self, ctx):
 		if self.title is None:
 			self.title = "Test suite from %s"%self.parent.sourceId
-		self._completeElementNext(base.Structure, ctx)
+		super().completeElement(ctx)
 
 	def expand(self, *args, **kwargs):
 		"""hand macro expansion to the RD.
