@@ -93,7 +93,7 @@ class MappedExpression(base.Structure):
 		"""checks that code content is a parseable python expression and that
 		the destination exists in the tableDef
 		"""
-		self._validateNext(MappedExpression)
+		super().validate()
 
 		if (self.content_ and self.source) or not (self.content_ or self.source):
 			raise base.StructureError("Map must have exactly one of source attribute"
@@ -440,7 +440,7 @@ class RowmakerDef(base.Structure, RowmakerMacroMixin):
 					nullExcs = "KeyError,"
 				self.feedObject("maps", base.makeStruct(MapRule, 
 					key=k, source=v, nullExcs=nullExcs))
-		self._completeElementNext(RowmakerDef, ctx)
+		super().completeElement(ctx)
 
 	def _getSourceFromColset(self, columns):
 		"""returns the source code for a mapper to a column set.
