@@ -37,7 +37,7 @@ from gavo.base.literals import (identity, #noflake:exported names
 	parseSPoint, getDefaultValueParsers, originalOrIdentity, parseBytes)
 
 from gavo.base.unitconv import ( #noflake: exported names
-	PLANCK_H, LIGHT_C)
+	PLANCK_H, LIGHT_C, BOLTZMANN_K)
 from gavo.rscdef.common import ( #noflake: exported names
 	getStandardPubDID, getAccrefFromStandardPubDID,
 	getDatalinkMetaLink,
