@@ -6,7 +6,7 @@ make instances.  For details, see Scripting in the reference
 documentation.
 """
 
-#c Copyright 2008-2021, the GAVO project <gavo@ari.uni-heidelberg.de>
+#c Copyright 2008-2022, the GAVO project <gavo@ari.uni-heidelberg.de>
 #c
 #c This program is free software, covered by the GNU GPL.  See the
 #c COPYING file in the source distribution.
@@ -241,10 +241,10 @@ class Script(base.Structure, base.RestrictionMixin):
 			raise base.StructureError("Invalid script type %s for %s elements"%(
 				self.type, self.parent.name_))
 
-		self._validateNext(Script)
+		super().validate()
 
 
-class ScriptingMixin(object):
+class ScriptingMixin(base.StructCallbacks):
 	"""A mixin that gives objects a getRunner method and a script attribute.
 
 	The getRunner() method returns a callable that takes the current table
