@@ -10,7 +10,7 @@ In the DaCHS, a resource descriptor typically sets up a schema in
 the database.
 """
 
-#c Copyright 2008-2021, the GAVO project <gavo@ari.uni-heidelberg.de>
+#c Copyright 2008-2022, the GAVO project <gavo@ari.uni-heidelberg.de>
 #c
 #c This program is free software, covered by the GNU GPL.  See the
 #c COPYING file in the source distribution.
@@ -36,6 +36,28 @@ from gavo.rscdef import scripting
 from gavo.rscdef import executing
 
 
+class ResdirAttribute(base.UnicodeAttribute):
+	"""An attribute representing an RD's resdir.
+
+	This is for resource's resdir attribute, which will by default
+	get the inputsDir prepended.  There is the special value "." that
+	means "the directory containing the RD", which is what people should
+	do now.
+
+	This will only work for RDs.
+
+	Note that without that, the resdir defaults to <inputsDir>/<schemaName>.
+	"""
+	def feedObject(self, instance, parsedValue):
+		setattr(self, f"_original_resdir_{self.name_}", parsedValue)
+		if parsedValue==".":
+			parsedValue = "/".join(instance.sourceId.split("/")[:-1])
+
+		parsedValue = os.path.join(
+			base.getConfig("inputsDir"), parsedValue)
+		super().feedObject(instance, parsedValue)
+
+
 class RD(base.Structure, base.ComputedMetaMixin, scripting.ScriptingMixin,
 		base.StandardMacroMixin, common.PrivilegesMixin):
 	"""A resource descriptor.
@@ -57,11 +79,12 @@ class RD(base.Structure, base.ComputedMetaMixin, scripting.ScriptingMixin,
 	# scripts for a while
 	acceptedScriptTypes = {}
 
-	_resdir = base.FunctionRelativePathAttribute("resdir", 
+	_resdir = ResdirAttribute("resdir", 
 		default=None, 
-		baseFunction=lambda instance: base.getConfig("inputsDir"),
 		description="Base directory for source files and everything else"
-			" belonging to the resource.", 
+			" belonging to the resource.  Use a single dot (.) to say 'the"
+			" directory the RD resides in', which is recommended in modern"
+			" DaCHS.", 
 		copyable=True)
 
 	_schema = base.UnicodeAttribute("schema", 
@@ -225,9 +248,10 @@ class RD(base.Structure, base.ComputedMetaMixin, scripting.ScriptingMixin,
 			base.ui.notifyWarning("RD %s: resource directory '%s' does not exist"%(
 				self.sourceId, self.resdir))
 
-		self._onElementCompleteNext(RD)
+		super().onElementComplete()
 
 	def _inferResdir(self, value):
+		# a callback for the schema attribute
 		if self.resdir is None:
 			self._resdir.feedObject(self, value)
 
@@ -253,6 +277,13 @@ class RD(base.Structure, base.ComputedMetaMixin, scripting.ScriptingMixin,
 			base.assertType(id, res, forceType)
 		return res
 
+	def getRelResdir(self):
+		"""returns the inputsDir-relative resource directory path.
+
+		This never has either a leading or a trailing path.
+		"""
+		return utils.getRelativePath(self.resdir, base.getConfig("inputsDir"))
+
 	def getAbsPath(self, relPath):
 		"""returns the absolute path for a resdir-relative relPath.
 		"""
@@ -591,7 +622,11 @@ def getRD(srcId, doQueries=True, restricted=False, useRD=None):
 		rd = useRD
 	
 	srcPath, inputFile = getRDInputStream(rd.sourceId)
-	refuseBlacklisted(srcId, srcPath)
+	try:
+		refuseBlacklisted(srcId, srcPath)
+	except utils.Error:
+		inputFile.close()
+		raise
 
 	# look for a context upstack and get the default parameters from there,
 	# overriding the parameters.
