@@ -158,7 +158,7 @@ class Core(base.Structure):
 		return repr(self)
 
 	def completeElement(self, ctx):
-		self._completeElementNext(Core, ctx)
+		super().completeElement(ctx)
 		self.initialize()
 		if self.inputTable is base.NotGiven:
 			self.inputTable = base.makeStruct(inputdef.InputTD)
