@@ -115,7 +115,7 @@ class InputKey(column.ParamBase):
 	_compiledPreparse = None
 
 	def completeElement(self, ctx):
-		self._completeElementNext(InputKey, ctx)
+		super().completeElement(ctx)
 		if self.restrictedMode and (
 				self.widgetFactory
 				or self.preparse):
@@ -138,7 +138,7 @@ class InputKey(column.ParamBase):
 				self.multiplicity = "single"
 
 	def onElementComplete(self):
-		self._onElementCompleteNext(InputKey)
+		super().onElementComplete()
 		# compute scaling if an input unit is given
 		self.scaling = None
 		if self.inputUnit:
@@ -493,7 +493,7 @@ class ContextGrammar(grammars.Grammar):
 	rejectExtras = False
 
 	def onElementComplete(self):
-		self._onElementCompleteNext(ContextGrammar)
+		super().onElementComplete()
 		if self.inputTD:
 			self.rejectExtras = self.inputTD.exclusive
 		else:
