@@ -114,10 +114,10 @@ class Publication(base.Structure, base.ComputedMetaMixin):
 				ctx.getInjected("resprop:%s#%s"%(
 					self.service.rd.sourceId, self.service.id), {}))
 		
-		self._completeElementNext(Publication, ctx)
+		super().completeElement(ctx)
 
 	def validate(self):
-		self._validateNext(Publication)
+		super().validate()
 		try:
 			renderers.getRenderer(self.render)
 		except KeyError:
@@ -171,7 +171,7 @@ class CustomPageFunction(base.Structure, base.RestrictionMixin):
 		" you will see it as ``data``.", copyable=True)
 
 	def onElementComplete(self):
-		self._onElementCompleteNext(CustomPageFunction)
+		super().onElementComplete()
 		vars = globals().copy()
 		vars["service"] = self.parent
 		vars["_FakeContext"] = _FakeContext
@@ -319,8 +319,6 @@ class Service(base.Structure, base.ComputedMetaMixin,
 	  all columns from the underlying database table with low enough
 	  verbLevel (essentially).  When this property is "True" (case-sensitive),
 		that's not done and only the service's output table is evaluated.
-	  set this property to the URL of its successor.  This will produce
-	  a 404 page with a link to the new service.
 	* fixedFormat -- if this is set to "True", the form renderer will
 	  not produce an output format selector (and we shouldn't produce
 	  DALI RESPONSEFORMAT metadata).
@@ -382,7 +380,7 @@ class Service(base.Structure, base.ComputedMetaMixin,
 		return "<Service %s at %s>"%(self.id, self.getSourcePosition())
 
 	def completeElement(self, ctx):
-		self._completeElementNext(Service, ctx)
+		super().completeElement(ctx)
 		if not self.allowed:
 			self.allowed.add("form")
 
@@ -425,7 +423,7 @@ class Service(base.Structure, base.ComputedMetaMixin,
 		ctx.addExitFunc(lambda rd, ctx: self._addAutomaticCapabilities())
 			
 	def onElementComplete(self):
-		self._onElementCompleteNext(Service)
+		super().onElementComplete()
 		
 		# Index custom render/data functions
 		self.nevowRenderers = {}
@@ -1112,5 +1110,3 @@ class Service(base.Structure, base.ComputedMetaMixin,
 			return base.META_CLASSES_FOR_KEYS["_related"](
 				self.getURL("howtocite", False),
 				title="Advice on citing this resource")
-	
-
