@@ -167,7 +167,7 @@ class CondDesc(base.Structure):
 			# use the column as input key; special renderers may want
 			# to do type mapping, but the default is to have plain input
 			self.inputKeys = [inputdef.InputKey.fromColumn(self.buildFrom)]
-		self._completeElementNext(CondDesc, ctx)
+		super().completeElement(ctx)
 
 	def expand(self, *args, **kwargs):
 		"""hands macro expansion requests (from phraseMakers) upwards.
@@ -365,7 +365,7 @@ class TableBasedCore(core.Core):
 			self.outputTable = outputdef.OutputTableDef.fromTableDef(
 				self.queriedTable, ctx)
 
-		self._completeElementNext(TableBasedCore, ctx)
+		super().completeElement(ctx)
 
 	def _fixNamePath(self, qTable):
 # callback from queriedTable to make it the default for namePath as well
@@ -576,7 +576,7 @@ class FixedQueryCore(core.Core, base.RestrictionMixin):
 	def completeElement(self, ctx):
 		if self.inputTable is base.NotGiven:
 			self.inputTable = base.makeStruct(inputdef.InputTD)
-		self._completeElementNext(FixedQueryCore, ctx)
+		super().completeElement(ctx)
 
 	def run(self, service, inputTable, queryMeta):
 		if self.writable:
