@@ -2,7 +2,7 @@
 The user interface to importing resources into the VO.
 """
 
-#c Copyright 2008-2021, the GAVO project <gavo@ari.uni-heidelberg.de>
+#c Copyright 2008-2022, the GAVO project <gavo@ari.uni-heidelberg.de>
 #c
 #c This program is free software, covered by the GNU GPL.  See the
 #c COPYING file in the source distribution.
@@ -13,6 +13,7 @@ import sys
 
 from gavo import api
 from gavo import base
+from gavo.protocols import obscore
 from gavo.protocols import tap
 from gavo.user import common
 
@@ -99,8 +100,8 @@ def process(opts, args):
 	for dd in dds:
 		if opts.metaOnly:
 			api.ui.notifyInfo("Updating meta for %s"%dd.id)
-			res = api.Data.create(dd, parseOptions=opts, connection=connection
-				).updateMeta(opts.metaPlusIndex)
+			res = api.Data.create(dd, parseOptions=opts, connection=connection)
+			res.updateMeta()
 
 		else:
 			api.ui.notifyInfo("Making data %s"%dd.getFullId())
@@ -108,6 +109,16 @@ def process(opts, args):
 			dbCatalogChanged = dbCatalogChanged or res.dbCatalogChanged()
 		if hasattr(res, "nAffected"):
 			api.ui.notifyInfo("Rows affected: %s"%res.nAffected)
+	
+	# Let's update the date updated independently of dachs pub; not many
+	# people bother to re-publish the RD just because they did a re-import.
+	if base.UnmanagedQuerier(connection).getTableType("dc.resources"):
+		# skip this during bootstrap
+		connection.execute("UPDATE dc.resources SET"
+			" dateupdated=CURRENT_TIMESTAMP,"
+			" rectimestamp=CURRENT_TIMESTAMP"
+			" WHERE sourcerd=%(rdid)s", {"rdid": rd.sourceId})
+
 	# We're committing here so that we don't lose all importing
 	# work just because some dependent messes up.
 	connection.commit()
@@ -116,6 +127,17 @@ def process(opts, args):
 		rd.updateMetaInDB(connection, "import")
 	connection.commit()
 
+	# re-indexing is a big deal because it may involve primary key
+	# operations and, in particular, clustering, which locks the
+	# table.  Let's take everything out of obscore before doing that.
+	if opts.metaPlusIndex:
+		with obscore.suspendFromObscore(rd, connection):
+			for dd in dds:
+				data = api.Data.create(dd, parseOptions=opts, connection=connection)
+				for t in data:
+					t.dropIndices()
+					t.makeIndices()
+
 	api.makeDependentsFor(dds, opts, connection, dbCatalogChanged)
 	connection.commit()
 
