@@ -24,6 +24,7 @@ The actual aquisition of the statistics is currently done in user.info
 
 from gavo import base
 from gavo import rsc
+from gavo import utils
 from gavo.user import info
 
 
@@ -88,7 +89,7 @@ def updateRDLevelMetadata(rd, conn):
 				{"value": value, "rdId": rd.sourceId})
 
 
-def updateTableLevelMetadata(
+def updateTableLevelStats(
 		td, 
 		conn,
 		samplePercent=None, 
@@ -135,7 +136,7 @@ def updateForRD(rd, conn, samplePercent=None, acquireColumnMeta=True):
 			if td.viewStatement and not td.getProperty("forceStats", False):
 				continue
 
-			updateTableLevelMetadata(
+			updateTableLevelStats(
 				td, conn, samplePercent, acquireColumnMeta)
 
 
@@ -155,6 +156,65 @@ def _getUpdatableRdIds():
 			"	WHERE nrows IS NOT NULL")]
 
 
+def dumpTableLevelStats(td, conn):
+	"""writes limits metadata for the table td.
+	"""
+	if not td.onDisk:
+		return
+	qName = td.getQName()
+
+	heading = f"Statistics for {qName}"
+	print("\n"+heading+"\n"+"-"*len(heading))
+
+	try:
+		print("|rows| = {}\n".format(next(conn.query(
+			"SELECT nrows FROM dc.tablemeta WHERE tablename=%(qName)s",
+			locals()))[0] or "<Unknown>"))
+	except StopIteration:
+		print("No metadata (table not imported)?")
+		return
+
+	statsTD = base.resolveCrossId("//dc_tables#simple_col_stats")
+	colNames = ("column_name min_value max_value percentile03"
+		" median percentile97 fill_factor").split()
+
+	stats = [["{:.5g}".format(v) if isinstance(v, float) 
+			else utils.makeEllipsis(str(v), 12, "…") for v in r] 
+		for r in conn.query(statsTD.getSimpleQuery(
+			colNames,
+			"tablename=%(tablename)s"),
+			{"tablename": td.getQName()})]
+	stats.sort()
+	print(utils.formatSimpleTable(stats, False, colNames))
+
+
+def dumpStatsForRD(rd, conn):
+	"""writes metadata for rd and its tables
+	"""
+	print("="*72)
+	rdId = rd.sourceId
+	print(f"Statistics for RD {rdId}")
+
+	try:
+		print("spatial converage {}".format(next(conn.query(
+			"SELECT spatial FROM dc.rdmeta WHERE sourcerd=%(rdId)s",
+			locals()))[0] or "<Unknown>"))
+	except StopIteration:
+		print("No RD stats.")
+	
+	else:
+		print("temporal converage {}".format(next(conn.query(
+			"SELECT temporal FROM dc.rdmeta WHERE sourcerd=%(rdId)s",
+			locals()))[0] or "<Unknown>"))
+
+		print("spectral converage {}".format(next(conn.query(
+			"SELECT spectral FROM dc.rdmeta WHERE sourcerd=%(rdId)s",
+			locals()))[0] or "<Unknown>"))
+
+	for td in rd.tables:
+		dumpTableLevelStats(td, conn)
+
+
 def parseCmdLine():
 	from argparse import ArgumentParser
 
@@ -166,13 +226,24 @@ def parseCmdLine():
 		action="store_true",
 		help="Only acquire table/resource-level metadata (rather than column"
 			" metadata, which usually takes a lot longer).")
-	parser.add_argument("-s", "--sample-percent", type=float, default=None,
-		dest="samplePercent", metavar="P",
+	parser.add_argument("-s", "--sample-percent", 
+		type=float, 
+		default=None,
+		dest="samplePercent", 
+		metavar="P",
 		help="Only look at P percent of the table to determine min/max/mean.")
-	parser.add_argument("itemId", help="Cross-RD reference of a table or"
+	parser.add_argument("-d", "--dump", 
+		action="store_true", 
+		default=False,
+		dest="dumpOnly", 
+		help="Do not obtain statistics but rather dump the results of the"
+			" last run")
+	parser.add_argument("itemId", 
+		nargs="+",
+		help="Cross-RD reference of a table or"
 		" RD to update, as in ds/q or ds/q#mytable; only RDs in inputsDir"
 		" can be updated.  A single ALL will expand to all RDs that already"
-		" have limits-obtained metadata.", nargs="+")
+		" have limits-obtained metadata.")
 	return parser.parse_args()
 
 
@@ -188,11 +259,17 @@ def main():
 			item = api.getReferencedElement(itemRef)
 
 			if isinstance(item, api.TableDef):
-				updateTableLevelMetadata(item, conn,
-					args.samplePercent, not args.tablesOnly)
+				if args.dumpOnly:
+					dumpTableLevelStats(item, conn)
+				else:
+					updateTableLevelStats(item, conn,
+						args.samplePercent, not args.tablesOnly)
 
 			elif isinstance(item, api.RD):
-				updateForRD(item, conn, args.samplePercent, not args.tablesOnly)
+				if args.dumpOnly:
+					dumpStatsForRD(item, conn)
+				else:
+					updateForRD(item, conn, args.samplePercent, not args.tablesOnly)
 				
 			else:
 				raise base.ReportableError(
