@@ -347,7 +347,7 @@ def iterColAttrsFITS(table):
 	hdr = table.header
 	for colInd in range(1, hdr["TFIELDS"]+1):
 		colMeta = [
-			("name", hdr[f"TTYPE{colInd}"]),
+			("name", re.sub("[^0-9a-z_]", "_", hdr[f"TTYPE{colInd}"].lower())),
 			("type", getTypeForFTFormat(
 				hdr[f"TFORM{colInd}"], hdr[f"TTYPE{colInd}"])),
 			("ucd", hdr.get(f"TUCD{colInd}", None)),
