@@ -32,14 +32,14 @@ from gavo import rscdesc  #noflake: for cache registration
 from gavo import utils
 
 
+CURRENT_SCHEMAVERSION = 32
+
+
 class _COMMIT(object):
 	"""A sentinel used by iterStatements.
 	"""
 
 
-CURRENT_SCHEMAVERSION = 30
-
-
 def getColumnNamesFor(tableId, connection):
 	"""returns (normalised) column names for tableId.
 
@@ -93,6 +93,7 @@ def iterEPNTAPTables(connection):
 			base.ui.notifyWarning(f"Published EPN-TAP table {tableName}"
 				" has no definition any more")
 
+
 class AnnotatedString(str):
 	"""a string with an annotation.
 	
@@ -879,6 +880,35 @@ class To30Upgrader(Upgrader):
 			create=True)
 
 
+class To31Upgrader(Upgrader):
+	version = 30
+
+	@classmethod
+	def u_10_update_ssa_fov_ucd(cls, connection):
+		"""Updating SSA published metadata for SSA 1.1 erratum 2 (instr.fov)"""
+		# Well, SSA metadata will actually fix itself (we might consider
+		# re-publishing the services so their tableset gets updated, but
+		# I'd say that's overkill.  Instead, let's just fix whatever
+		# has a problem in the TAP_SCHEMA.
+		from gavo.protocols import tap
+		for rdId, in connection.query(
+				"SELECT DISTINCT sourcerd FROM tap_schema.columns"
+				"  WHERE ucd='instr.fov'"):
+			tap.publishToTAP(base.caches.getRD(rdId), connection)
+
+
+class To32Upgrader(Upgrader):
+	version = 31
+
+	@classmethod
+	def u_10_update_obscore_defs(cls, connection):
+		"""updating obscore definitions to use reals for spectral"""
+		if relationExists("ivoa._obscoresources", connection):
+			dd = base.caches.getRD("//obscore", doQueries=False
+				).getById("refreshAfterSchemaUpdate")
+			rsc.makeData(dd, connection=connection)
+
+
 def iterStatements(startVersion, endVersion=CURRENT_SCHEMAVERSION, 
 		upgraders=None):
 	"""yields all upgraders from startVersion to endVersion in sequence.
@@ -982,7 +1012,8 @@ def main():
 		with base.getTableConn() as conn:
 			sys.exit(dumpExtensionUpdater(conn))
 	else:
-		upgrade(args.forceDBVersion)
+		with base.ui.suspended("ScriptRunning"):
+			upgrade(args.forceDBVersion)
 	
 	if args.updateTAPSchema:
 		with base.getWritableAdminConn() as conn:
