@@ -60,7 +60,8 @@ from gavo.utils.misctricks import (Undefined, QuotedName, getfirst,
 	parseKVLine, makeKVLine,
 	StreamBuffer, CaseSemisensitiveDict,
 	NotInstalledModuleStub, grouped,
-	getCleanBytes, getDirtyBytes)
+	getCleanBytes, getDirtyBytes,
+	RateLimiter)
 
 from gavo.utils.ostricks import (safeclose, 
 	urlopenRemote, setUserAgent,
@@ -76,7 +77,7 @@ from gavo.utils.serializers import (defaultMFRegistry, registerDefaultMF)
 from gavo.utils.stanxml import (ElementTree, xmlrender, xmlwrite,
 	escapeAttrVal, escapePCDATA, registerPrefix, getPrefixInfo)
 
-from gavo.utils.texttricks import (formatSize, 
+from gavo.utils.texttricks import (formatSize, formatFloat,
 	makeEllipsis, makeLeftEllipsis, makeSourceEllipsis,
 	floatRE, dateRE, datetimeRE, identifierPattern, looksLikeURLPat,
 	datetimeToRFC2616, 
