@@ -15,6 +15,7 @@ import io
 import os
 import re
 import struct
+import time
 import threading
 import urllib.request, urllib.error, urllib.parse
 import zlib
@@ -214,6 +215,33 @@ class Undefined(object, metaclass=_UndefinedType):
 		raise TypeError("Undefined cannot be instantiated.")
 
 
+class RateLimiter:
+	"""A class that helps limit rates of events.
+
+	You construct it with a timeout (in seconds) and then protect things you want
+	to rate-limit with "if rl.inDeadtime(key): skip".  The key is an identifier
+	for what it is that you want to limit (e.g., the sort of an event, so that
+	different events can share a rate limiter).
+
+	If you have many events that usually need rate limiting, you'd have
+	to revisit this implementation -- this is really for when rate limiting
+	is the exception.
+	"""
+	def __init__(self, timeout):
+		self.timeout = timeout
+		self.lastEvents = {}
+	
+	def inDeadtime(self, key):
+		now = time.time()
+
+		# no reason to have this work in 1970
+		if self.lastEvents.get(key, 0)+self.timeout>now:
+			return True
+
+		self.lastEvents[key] = now
+		return False
+
+
 @functools.total_ordering
 class QuotedName(object):
 	"""A string-like thing basically representing SQL delimited identifiers.
@@ -238,6 +266,8 @@ class QuotedName(object):
 	"foo" "foo""l"
 	>>> "Foo"<n1, n1>"bar"
 	(False, True)
+	>>> QuotedName('7oh-no"+rob').makeIdentifier()
+	'id7oh2dno222brob'
 	"""
 	def __init__(self, name):
 		self.name = name
@@ -278,7 +308,22 @@ class QuotedName(object):
 
 	def capitalize(self):  # service for table head and such
 		return self.name.capitalize()
-	
+
+	def makeIdentifier(self):
+		"""returns self as something usable as a SQL regular identifier.
+
+		This will be rather unreadable if there's a substantial number
+		of non-letters in there, and of course there's no absolute
+		guarantee that doesn't clash with actual identifiers.
+
+		This is *not* for SQL serialisation but mainly for generating sqlKey,
+		where this kind of thing ends up in %(name)s patterns.
+		"""
+		id = re.sub("[^a-zA-Z0-9]", lambda mat: "%x"%ord(mat.group(0)), self.name)
+		if not re.match("[a-zA-Z]", id):
+			id = "id"+id
+		return id
+
 	def __add__(self, other):  # for disambiguateColumns
 		return QuotedName(self.name+other)
 
