@@ -66,3 +66,19 @@ if not hasattr(functools, "cached_property"): # pragma: no cover
 			return val
 
 	functools.cached_property = cached_property
+
+
+# Work around a rather severe openssl bug leading to presumably
+# exploitable crashes https://twistedmatrix.com/trac/ticket/9764
+from OpenSSL import SSL
+
+def patch_openssl():
+	original = SSL.Context.__init__
+
+	def newInit(self, method):
+		original(self, method)
+		self.set_session_cache_mode(SSL.SESS_CACHE_OFF)
+	
+	SSL.Context.__init__ = newInit
+
+patch_openssl()
