@@ -121,7 +121,7 @@ class SPoint(PgSAdapter):
 	"""
 	pgType = "spoint"
 	checkedAttributes = ["x", "y"]
-	pattern = re.compile(r"\s*\(\s*([0-9.e-]+)\s*,\s*([0-9.e-]+)\s*\)")
+	pattern = re.compile(r"\s*\(\s*([0-9.eNa-]+)\s*,\s*([0-9.eNa-]+)\s*\)")
 
 	def __init__(self, x, y):
 		self.x, self.y = float(x), float(y)
