@@ -2,12 +2,12 @@
 Formatting, text manipulation, string constants, and such.
 """
 
-#c Copyright 2008-2021, the GAVO project <gavo@ari.uni-heidelberg.de>
+#c Copyright 2008-2022, the GAVO project <gavo@ari.uni-heidelberg.de>
 #c
 #c This program is free software, covered by the GNU GPL.  See the
 #c COPYING file in the source distribution.
 
-
+import calendar
 import datetime
 import functools
 import math
@@ -59,14 +59,14 @@ def formatSize(val, sf=1):
 		return "%.*fGiB"%(sf, val/1024./1024./1024)
 
 
-def makeEllipsis(aStr, maxLen=60):
+def makeEllipsis(aStr, maxLen=60, ellChars="..."):
 	"""returns aStr cropped to maxLen if necessary.
 
 	Cropped strings are returned with an ellipsis marker.
 	"""
 	aStr = re.sub("\s+", " ", aStr)
 	if len(aStr)>maxLen:
-		return aStr[:maxLen-3]+"..."
+		return aStr[:maxLen-len(ellChars)]+ellChars
 	return aStr
 
 
@@ -379,14 +379,67 @@ def fracHoursToDeg(fracHours):
 	return float(fracHours)*360./24.
 
 
-def degToHms(deg, sepChar=" ", secondFracs=3):
+def _formatSecs(seconds, secondFracs, truncate):
+	"""returns a string representation of the float seconds with secondFracs
+	fractionals.
+
+	With truncate=True, we truncate rather than round.
+
+	Behaviour with negative seconds is undefined for now (let's see if
+	we ever need that).
+	>>> _formatSecs(0, 0, False)
+	'00'
+	>>> _formatSecs(0, 1, False)
+	'00.0'
+	>>> _formatSecs(3.689, 2, False)
+	'03.69'
+	>>> _formatSecs(3.689, 1, False)
+	'03.7'
+	>>> _formatSecs(3.689, 0, False)
+	'04'
+	>>> _formatSecs(3.689, 2, True)
+	'03.68'
+	>>> _formatSecs(3.689, 1, True)
+	'03.6'
+	>>> _formatSecs(3.689, 0, True)
+	'03'
+	"""
+	if truncate:
+		fracPart, intPart = math.modf(seconds)
+		secPart = "%02d"%int(intPart)
+		if secondFracs>0:
+			secPart += ("%019.17f"%fracPart)[1:secondFracs+2]
+	else:
+		if secondFracs<1:
+			secondFracs = -1
+		secPart = "%0*.*f"%(secondFracs+3, secondFracs, seconds)
+	
+	return secPart
+
+
+@codetricks.document
+def degToHms(deg, 
+		sepChar=" ", 
+		secondFracs=3, 
+		truncate=False):
 	"""converts a float angle in degrees to an time angle (hh:mm:ss.mmm).
 
+	This takes a lot of optional arguments:
+
+	* sepChar is the char separating the components
+	* secondFracs is the number for fractional seconds to generate
+	* truncate can be set to True if fractional seconds should be truncated
+	  rather then rounded (as necessary for building IAU identifiers)
+
 	>>> degToHms(0)
 	'00 00 00.000'
-	>>> degToHms(122.056, secondFracs=1)
-	'08 08 13.4'
-	>>> degToHms(-0.056, secondFracs=0)
+	>>> degToHms(122.057, secondFracs=1)
+	'08 08 13.7'
+	>>> degToHms(122.057, secondFracs=1, truncate=True)
+	'08 08 13.6'
+	>>> degToHms(-0.055, secondFracs=0)
+	'-00 00 13'
+	>>> degToHms(-0.055, secondFracs=0, truncate=True)
 	'-00 00 13'
 	>>> degToHms(-1.056, secondFracs=0)
 	'-00 04 13'
@@ -401,15 +454,32 @@ def degToHms(deg, sepChar=" ", secondFracs=3):
 		deg = -deg
 	rest, hours = math.modf(deg/360.*24)
 	rest, minutes = math.modf(rest*60)
-	if secondFracs<1:
-		secondFracs = -1
-	return sign+sepChar.join(["%02d"%int(hours), "%02d"%abs(int(minutes)), 
-		"%0*.*f"%(secondFracs+3, secondFracs, abs(rest*60))])
+
+	return sign+sepChar.join([
+		"%02d"%int(hours), 
+		"%02d"%abs(int(minutes)), 
+		_formatSecs(abs(rest*60), secondFracs, truncate)])
 
 
-def degToDms(deg, sepChar=" ", secondFracs=2):
+@codetricks.document
+def degToDms(deg, 
+		sepChar=" ", 
+		secondFracs=2, 
+		preserveLeading=False,
+		truncate=False):
 	"""converts a float angle in degrees to a sexagesimal string.
 
+	This takes a lot of optional arguments:
+
+	* sepChar is the char separating the components
+	* secondFracs is the number for fractional seconds to generate
+	* preserveLeading can be set to True if leading zeroes should be
+	  preserved
+	* truncate can be set to True if fractional seconds should be truncated
+	  rather then rounded (as necessary for building IAU identifiers)
+
+	>>> degToDms(-3.24722, "", 0, True, True)
+	'-031449'
 	>>> degToDms(0)
 	'+0 00 00.00'
 	>>> degToDms(-0.25)
@@ -427,8 +497,32 @@ def degToDms(deg, sepChar=" ", secondFracs=2):
 	rest, minutes = math.modf(rest*60)
 	if secondFracs==0:
 		secondFracs = -1
-	return sepChar.join(["%s%d"%(sign, int(degs)), "%02d"%abs(int(minutes)), 
-		"%0*.*f"%(secondFracs+3, secondFracs, abs(rest*60))])
+	
+	if preserveLeading:
+		degFormat = "%s%02d"
+	else:
+		degFormat = "%s%d"
+
+	return sepChar.join([
+		degFormat%(sign, int(degs)), 
+		"%02d"%abs(int(minutes)), 
+		_formatSecs(abs(rest*60), secondFracs, truncate)])
+
+
+@codetricks.document
+def makeIAUId(prefix, long, lat, longSec=0, latSec=0):
+	"""returns an (equatorial) IAU identifier for an object at long and lat.
+
+	The rules are given on https://cds.unistra.fr/Dic/iau-spec.html
+
+	The prefix, including the system identifier, you have to pass in.
+	You cannot build identifiers using only minutes precision.
+	If you want to include sub-arcsec precision, pass in longSec and/or
+	latSec (the number of factional seconds to preserve).
+	"""
+	longPart = degToHms(long, "", longSec, True)
+	latPart = degToDms(lat, "", latSec, True, True)
+	return f"{prefix}{longPart}{latPart}"
 
 
 def datetimeToRFC2616(dt):
@@ -473,12 +567,17 @@ _isoDTRE = re.compile(r"(?P<year>\d\d\d\d)-?(?P<month>\d\d)-?(?P<day>\d\d)"
 
 
 @codetricks.document
-def parseISODT(literal):
+def parseISODT(literal, useTime=False):
 	"""returns a datetime object for a ISO time literal.
 
 	There's no real timezone support yet, but we accept and ignore various
 	ways of specifying UTC.
 
+	By default, this uses plain python datetime because it usually covers a large
+	date range than the time module.  The downside is that it does not know about
+	leap seconds.  Pass useTime=True to go through time tuples, which know how to
+	deal with them (but may not deal with dates far in the past or future).
+
 	>>> parseISODT("1998-12-14")
 	datetime.datetime(1998, 12, 14, 0, 0)
 	>>> parseISODT("1998-12-14T13:30:12")
@@ -491,6 +590,11 @@ def parseISODT(literal):
 	datetime.datetime(1998, 12, 14, 13, 30, 12)
 	>>> parseISODT("19981214T133012+00:00")
 	datetime.datetime(1998, 12, 14, 13, 30, 12)
+	>>> parseISODT("2016-12-31T23:59:60")
+	Traceback (most recent call last):
+	ValueError: second must be in 0..59
+	>>> parseISODT("2016-12-31T23:59:60", useTime=True)
+	datetime.datetime(2017, 1, 1, 1, 0)
 	>>> parseISODT("junk")
 	Traceback (most recent call last):
 	ValueError: Bad ISO datetime literal: junk (required format: yyyy-mm-ddThh:mm:ssZ)
@@ -510,9 +614,18 @@ def parseISODT(literal):
 		parts["secFracs"] = 0
 	else:
 		parts["secFracs"] = "0"+parts["secFracs"]
-	return datetime.datetime(int(parts["year"]), int(parts["month"]),
-		int(parts["day"]), int(parts["hour"]), int(parts["minute"]), 
-		int(parts["seconds"]), int(float(parts["secFracs"])*1000000))
+	
+	if useTime:
+		return datetime.datetime.fromtimestamp(
+			calendar.timegm((
+				int(parts["year"]), int(parts["month"]), int(parts["day"]),
+				int(parts["hour"]), int(parts["minute"]), int(parts["seconds"]),
+				-1, -1, -1)))
+
+	else:
+		return datetime.datetime(int(parts["year"]), int(parts["month"]),
+			int(parts["day"]), int(parts["hour"]), int(parts["minute"]), 
+			int(parts["seconds"]), int(float(parts["secFracs"])*1000000))
 
 
 _SUPPORTED_DT_FORMATS =[
@@ -561,6 +674,7 @@ def roundToSeconds(dt):
 	else:
 		return dt.replace(microsecond=0, tzinfo=None)
 
+
 def formatISODT(dt):
 	"""returns some ISO8601 representation of a datetime instance.
 
@@ -593,6 +707,28 @@ def formatISODT(dt):
 	return roundToSeconds(dt).isoformat()+"Z"
 
 
+@codetricks.document
+def formatFloat(f):
+	"""returns floating-point numbers somewhat suitable for human consumption.
+
+	The idea of this function is to slowly migrate ad-hoc formatting of
+	this kind that's in all kind of different places in DaCHS here and
+	thus have a central knob we can eventually use to adapt to tastes.
+
+	>>> formatFloat(1)
+	'1'
+	>>> formatFloat(1/3)
+	'0.333333'
+	>>> formatFloat(-1/3e20)
+	'-3.33333e-21'
+	>>> formatFloat(math.pi)
+	'3.14159'
+	>>> formatFloat(20000000.23)
+	'2e+07'
+	"""
+	return "{:.6g}".format(f)
+
+
 class NameMap(object):
 	"""is a name mapper fed from a simple text file.
 
