@@ -270,8 +270,7 @@ class GavoRenderMixin(common.CommonRenderers):
 			explanation = " (give an empty user name in the dialog popping up)"
 		else:
 			targetURL = urlpath.URLPath.fromString("/login")
-			targetURL.query = "nextURL=%s"%urllib.parse.quote(
-				base.makeAbsoluteURL(request.uri))
+			targetURL.query = "nextURL=%s"%urllib.parse.quote(request.uri)
 			anchorText = "Log in"
 			explanation = ""
 
