@@ -260,7 +260,6 @@ class SCSRenderer(DALRenderer):
 	version = "1.0"
 	parameterStyle = "dali"
 	standardId = "ivo://ivoa.net/std/ConeSearch"
-	defaultOutputFormat = "votable1.1"
 
 	# move the ucdCasts from formatOutput here.
 	_outputTableCasts = {}
@@ -275,10 +274,11 @@ class SCSRenderer(DALRenderer):
 			return
 
 		request.setHeader("content-type", base.votableType)
-		votable.write(V.VOTABLE11[
+		votable.write(V.VOTABLE[
 			V.DESCRIPTION[base.getMetaText(self.service, "description")],
-			V.INFO(ID="Error", name="Error",
-					value=str(msg).replace('"', '\\"'))], request)
+			V.RESOURCE[
+				V.INFO(ID="Error", name="Error",
+						value=str(msg).replace('"', '\\"')),]], request)
 		request.write("\n")
 		request.finish()
 
